@@ -8,6 +8,7 @@
 #include "setup_module_auto_defines.h"
 #include "object_cm_iso157652_tx_message.h"
 #include "object_cm_iso157652_rx_message.h"
+#include "object_ics_device_status.h"
 
 #ifdef _cplusplus
 extern "C" {
@@ -71,6 +72,12 @@ PyObject* meth_get_active_vnet_channel(PyObject* self, PyObject* args);
 PyObject* meth_set_active_vnet_channel(PyObject* self, PyObject* args);
 PyObject* meth_override_library_name(PyObject* self, PyObject* args);
 PyObject* meth_get_library_path(PyObject* self);
+PyObject* meth_set_bit_rate(PyObject* self, PyObject* args);
+PyObject* meth_set_bit_rate(PyObject* self, PyObject* args);
+PyObject* meth_set_fd_bit_rate(PyObject* self, PyObject* args);
+PyObject* meth_set_bit_rate_ex(PyObject* self, PyObject* args);
+PyObject* meth_get_timestamp_for_msg(PyObject* self, PyObject* args);
+PyObject* meth_get_device_status(PyObject* self, PyObject* args);
 
 #ifdef _cplusplus
 }
@@ -86,8 +93,12 @@ PyObject* meth_get_library_path(PyObject* self);
 #define _DOC_FIND_DEVICES \
     MODULE_NAME".find_devices(device_type="MODULE_NAME".NEODEVICE_ALL)\n" \
     "\n" \
+    "Finds all connected devices and returns a tuple of :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"` for use in :func:`"MODULE_NAME".open_device`\n" \
+    "\n" \
     "Args:\n" \
     "\tdevice_type (int): Accepts "MODULE_NAME".NEODEVICE_* Macros\n\n" \
+    "\t*New in 3.0 (803):*\n\n" \
+    "\tdevice_type (List/Tuple): Accepts a Container of "MODULE_NAME".NEODEVICE_* Macros\n\n" \
     "\tstOptionsOpenNeoEx (int): Usually ics.NETID_CAN, if needed\n\n" \
     "\n" \
     "Raises:\n" \
@@ -99,6 +110,11 @@ PyObject* meth_get_library_path(PyObject* self);
     "\t>>> for device in ics.find_devices():\n" \
     "\t...     print(device.Name, device.SerialNumber)\n" \
     "\t...\n" \
+    "\tneoVI FIRE 59886\n" \
+    "\n*New in 3.0 (803):*\n" \
+    "\t>>> for device in ics.find_devices([ics.NEODEVICE_FIRE, ics.NEODEVICE_VCAN3]):\n" \
+    "\t...     print(device.Name, device.SerialNumber)\n" \
+    "\t...\n" \
     "\tneoVI FIRE 59886\n"
 
 
@@ -1021,6 +1037,92 @@ PyObject* meth_get_library_path(PyObject* self);
     "\t>>> ics.find_devices()\n" \
     "\t(<ics.NeoDevice object at 0x00284C50>, <ics.NeoDevice object at 0x007C9A10>)\n"
 
+#define _DOC_SET_BIT_RATE \
+    MODULE_NAME".set_bit_rate(device, BitRate, NetworkID)\n" \
+    "\n" \
+    "Sets the bitrate for a given Network ID on the device..\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`): :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`"MODULE_NAME".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tInt: None.\n" \
+    "\n"
+
+#define _DOC_SET_FD_BIT_RATE \
+    MODULE_NAME".set_fd_bit_rate(device, BitRate, NetworkID)\n" \
+    "\n" \
+    "Sets the FD bitrate for a given Network ID on the device..\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`): :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`"MODULE_NAME".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tInt: None.\n" \
+    "\n"
+
+#define _DOC_SET_BIT_RATE_EX \
+    MODULE_NAME".set_fd_bit_rate_ex(device, BitRate, NetworkID, iOptions)\n" \
+    "\n" \
+    "Sets the bitrate for a given Network ID on the device with extended options.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`): :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`"MODULE_NAME".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tInt: None.\n" \
+    "\n"
+
+#define _DOC_GET_TIMESTAMP_FOR_MSG \
+    MODULE_NAME".get_timestamp_for_msg(device, msg)\n" \
+    "\n" \
+    "Calculates the timestamp for a message.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`): :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`\n\n" \
+    "\n" \
+    "\tmsg (:class:`"MODULE_NAME"."SPY_MESSAGE_OBJECT_NAME"`): :class:`"MODULE_NAME"."SPY_MESSAGE_OBJECT_NAME"`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`"MODULE_NAME".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tFloat: Timestamp for the message.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> msgs, error_count = ics.get_messages(d)\n" \
+    "\t>>> ics.get_timestamp_for_msg(d, msgs[0])\n" \
+    "\t354577568.9145524\n" \
+
+#define _DOC_GET_DEVICE_STATUS \
+    MODULE_NAME".get_device_status(device)\n" \
+    "\n" \
+    "Returns the device status.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`): :class:`"MODULE_NAME"."NEO_DEVICE_OBJECT_NAME"`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`"MODULE_NAME".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\t(:class:`"MODULE_NAME"."ICS_DEVICE_STATUS_OBJECT_NAME"`).\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> status = ics.get_device_status(d)\n" \
+    "\t>>> status.fire2Status.ethernetActivationLineEnabled\n" \
+    "\t0\n" \
 
 static PyMethodDef IcsMethods[] = {
     _EZ_ICS_STRUCT_METHOD("find_devices", "FindNeoDevices", (PyCFunction)meth_find_devices, METH_VARARGS | METH_KEYWORDS, _DOC_FIND_DEVICES),
@@ -1084,6 +1186,12 @@ static PyMethodDef IcsMethods[] = {
 
     _EZ_ICS_STRUCT_METHOD("get_active_vnet_channel", "icsneoGetActiveVNETChannel", meth_get_active_vnet_channel, METH_VARARGS, _DOC_GET_ACTIVE_VNET_CHANNEL),
     _EZ_ICS_STRUCT_METHOD("set_active_vnet_channel", "icsneoSetActiveVNETChannel", meth_set_active_vnet_channel, METH_VARARGS, _DOC_SET_ACTIVE_VNET_CHANNEL),
+    _EZ_ICS_STRUCT_METHOD("set_bit_rate", "icsneoSetBitRate", meth_set_bit_rate, METH_VARARGS, _DOC_SET_BIT_RATE),
+    _EZ_ICS_STRUCT_METHOD("set_fd_bit_rate", "icsneoSetFDBitRate", meth_set_fd_bit_rate, METH_VARARGS, _DOC_SET_FD_BIT_RATE),
+    _EZ_ICS_STRUCT_METHOD("set_bit_rate_ex", "icsneoSetBitRateEx", meth_set_bit_rate_ex, METH_VARARGS, _DOC_SET_BIT_RATE_EX),
+    _EZ_ICS_STRUCT_METHOD("get_timestamp_for_msg", "icsneoGetTimeStampForMsg", meth_get_timestamp_for_msg, METH_VARARGS, _DOC_GET_TIMESTAMP_FOR_MSG),
+    _EZ_ICS_STRUCT_METHOD("get_device_status", "icsneoGetDeviceStatus", meth_get_device_status, METH_VARARGS, _DOC_GET_DEVICE_STATUS),
+
     {"override_library_name", (PyCFunction)meth_override_library_name, METH_VARARGS, _DOC_OVERRIDE_LIBRARY_NAME},
     {"get_library_path", (PyCFunction)meth_get_library_path, METH_NOARGS, ""},
 
